@@ -13,6 +13,7 @@ pub struct PublicKeyWithTime {
     pub priv_key_creation_time: u64,
 }
 
+#[derive(Debug)]
 pub struct PublicPeer {
     pub endpoint: String,
     pub wg_port: u16,
@@ -35,6 +36,8 @@ pub struct StaticConfigurationBuilder {
     peers: HashMap<Ipv4Addr, PublicPeer>,
     use_tui: Option<bool>,
     use_existing_interface: Option<bool>,
+    network_yaml_filename: Option<String>,
+    peer_yaml_filename: Option<String>,
 }
 impl StaticConfigurationBuilder {
     pub fn new() -> Self {
@@ -92,6 +95,14 @@ impl StaticConfigurationBuilder {
         self.use_existing_interface = Some(use_existing_interface);
         self
     }
+    pub fn network_yaml_filename<T: Into<String>>(mut self, fname: T) -> Self {
+        self.network_yaml_filename = Some(fname.into());
+        self
+    }
+    pub fn peer_yaml_filename<T: Into<String>>(mut self, fname: T) -> Self {
+        self.peer_yaml_filename = Some(fname.into());
+        self
+    }
     pub fn build(self) -> StaticConfiguration {
         let peer_cnt = self.peers.len();
         StaticConfiguration {
@@ -109,10 +120,13 @@ impl StaticConfigurationBuilder {
             peer_cnt,
             use_tui: self.use_tui.unwrap(),
             use_existing_interface: self.use_existing_interface.unwrap(),
+            network_yaml_filename: self.network_yaml_filename.unwrap(),
+            peer_yaml_filename: self.peer_yaml_filename,
         }
     }
 }
 
+#[derive(Debug)]
 pub struct StaticConfiguration {
     pub name: String,
     pub ip_list: Vec<IpAddr>,
@@ -128,6 +142,8 @@ pub struct StaticConfiguration {
     pub peer_cnt: usize,
     pub use_tui: bool,
     pub use_existing_interface: bool,
+    pub network_yaml_filename: String,
+    pub peer_yaml_filename: Option<String>,
 }
 
 impl StaticConfiguration {
